@@ -1,7 +1,8 @@
 <?php
 /**
  * Mahara: Electronic portfolio, weblog, resume builder and social networking
- * Copyright (C) 2006-2008 Catalyst IT Ltd (http://www.catalyst.net.nz)
+ * Copyright (C) 2006-2009 Catalyst IT Ltd and others; see:
+ *                         http://wiki.mahara.org/Contributors
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -20,7 +21,7 @@
  * @subpackage admin
  * @author     Catalyst IT Ltd
  * @license    http://www.gnu.org/copyleft/gpl.html GNU GPL
- * @copyright  (C) 2006-2008 Catalyst IT Ltd http://catalyst.net.nz
+ * @copyright  (C) 2006-2009 Catalyst IT Ltd http://catalyst.net.nz
  *
  */
 
@@ -35,13 +36,13 @@ define('SECTION_PLUGINTYPE', 'core');
 define('SECTION_PLUGINNAME', 'admin');
 define('SECTION_PAGE', 'adminusers');
 require_once('pieforms/pieform.php');
-$smarty = smarty();
+require_once('activity.php');
 
 // Get users who are currently administrators
 // @todo later, exclude the user with uid 1
 $adminusers = get_column('usr', 'id', 'admin', 1, 'deleted', 0);
 
-$form = array(
+$form = pieform(array(
     'name' => 'adminusers',
     'elements' => array(
         'users' => array(
@@ -51,6 +52,11 @@ $form = array(
             'filter' => false,
             'lefttitle' => get_string('potentialadmins', 'admin'),
             'righttitle' => get_string('currentadmins', 'admin'),
+            'searchparams' => array(
+                'query' => '',
+                'limit' => 250,
+                'orderby' => 'lastname',
+            ),
             'rules' => array(
                 'required' => true
             )
@@ -60,7 +66,7 @@ $form = array(
             'value' => get_string('submit')
         )
     )
-);
+));
 
 function adminusers_submit(Pieform $form, $values) {
     global $SESSION;
@@ -78,8 +84,9 @@ function adminusers_submit(Pieform $form, $values) {
     redirect('/admin/users/admins.php');
 }
 
-$smarty->assign('adminusersform', pieform($form));
-$smarty->assign('heading', get_string('adminusers', 'admin'));
+$smarty = smarty();
+$smarty->assign('adminusersform', $form);
+$smarty->assign('PAGEHEADING', hsc(TITLE));
 $smarty->display('admin/users/admin.tpl');
 
 ?>
