@@ -1,7 +1,8 @@
 <?php
 /**
  * Mahara: Electronic portfolio, weblog, resume builder and social networking
- * Copyright (C) 2006-2008 Catalyst IT Ltd (http://www.catalyst.net.nz)
+ * Copyright (C) 2006-2009 Catalyst IT Ltd and others; see:
+ *                         http://wiki.mahara.org/Contributors
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -20,7 +21,7 @@
  * @subpackage admin
  * @author     Catalyst IT Ltd
  * @license    http://www.gnu.org/copyleft/gpl.html GNU GPL
- * @copyright  (C) 2006-2008 Catalyst IT Ltd http://catalyst.net.nz
+ * @copyright  (C) 2006-2009 Catalyst IT Ltd http://catalyst.net.nz
  *
  */
 
@@ -35,12 +36,12 @@ define('SECTION_PLUGINTYPE', 'core');
 define('SECTION_PLUGINNAME', 'admin');
 define('SECTION_PAGE', 'staffusers');
 require_once('pieforms/pieform.php');
-$smarty = smarty();
+require_once('activity.php');
 
 // Get users who are currently staff
 $staffusers = get_column('usr', 'id', 'staff', 1, 'deleted', 0);
 
-$form = array(
+$form = pieform(array(
     'name' => 'staffusers',
     'elements' => array(
         'users' => array(
@@ -49,14 +50,19 @@ $form = array(
             'defaultvalue' => $staffusers,
             'filter' => false,
             'lefttitle' => get_string('potentialstaff', 'admin'),
-            'righttitle' => get_string('currentstaff', 'admin')
+            'righttitle' => get_string('currentstaff', 'admin'),
+            'searchparams' => array(
+                'query' => '',
+                'limit' => 250,
+                'orderby' => 'lastname',
+            ),
         ),
         'submit' => array(
             'type' => 'submit',
             'value' => get_string('submit')
         )
     )
-);
+));
 
 function staffusers_submit(Pieform $form, $values) {
     global $SESSION;
@@ -75,8 +81,9 @@ function staffusers_submit(Pieform $form, $values) {
     redirect('/admin/users/staff.php');
 }
 
-$smarty->assign('staffusersform', pieform($form));
-$smarty->assign('heading', get_string('staffusers', 'admin'));
+$smarty = smarty();
+$smarty->assign('staffusersform', $form);
+$smarty->assign('PAGEHEADING', hsc(TITLE));
 $smarty->display('admin/users/staff.tpl');
 
 ?>
