@@ -98,7 +98,9 @@ class LeapImportResume extends LeapImportArtefactPlugin {
         $isability     = PluginImportLeap::is_rdf_type($entry, $importer, 'ability');
         $isachievement = PluginImportLeap::is_rdf_type($entry, $importer, 'achievement');
         $isactivity    = PluginImportLeap::is_rdf_type($entry, $importer, 'activity');
+        $isaffiliation = PluginImportLeap::is_rdf_type($entry, $importer, 'affiliation');
         $isresource    = PluginImportLeap::is_rdf_type($entry, $importer, 'resource');
+        $ispublication = PluginImportLeap::is_rdf_type($entry, $importer, 'publication');
 
         // Goals, cover letter & interests
         if ($isentry && $correctplugintype) {
@@ -159,7 +161,7 @@ class LeapImportResume extends LeapImportArtefactPlugin {
 
         // Books
         $other_required_entries = array();
-        if (($isresource || $isentry) && PluginImportLeap::is_correct_category_scheme($entry, $importer, 'resource_type', 'Printed')) {
+        if (($ispublication || $isresource || $isentry) && PluginImportLeap::is_correct_category_scheme($entry, $importer, 'resource_type', 'Printed')) {
             // If it exists, the related achievement will be the user's role in 
             // relation to the book
             foreach ($entry->link as $link) {
@@ -188,7 +190,7 @@ class LeapImportResume extends LeapImportArtefactPlugin {
             // the qualification the user gained in relation to this entry
             foreach ($entry->link as $link) {
                 if (!isset($other_required_entries['achievement'])
-                    && $importer->curie_equals($link['rel'], PluginImportLeap::NS_LEAP, 'supports') && isset($link['href'])) {
+                    && $importer->curie_equals($link['rel'], $importer->get_leap2a_namespace(), 'supports') && isset($link['href'])) {
                     if ($potentialqualification = $importer->get_entry_by_id((string)$link['href'])) {
                         if (PluginImportLeap::is_rdf_type($potentialqualification, $importer, 'achievement')) {
                             // We have a related achievement!
@@ -212,7 +214,7 @@ class LeapImportResume extends LeapImportArtefactPlugin {
 
         // Professional Membership
         $correctmaharatype = count($entry->xpath('mahara:artefactplugin[@mahara:plugin="resume" and @mahara:type="pseudo:membership"]')) == 1;
-        if ($isactivity && $correctmaharatype) {
+        if (($isactivity && $correctmaharatype) || $isaffiliation) {
             return array(array(
                 'strategy' => self::STRATEGY_IMPORT_AS_MEMBERSHIP,
                 'score'    => 100,
@@ -278,7 +280,7 @@ class LeapImportResume extends LeapImportArtefactPlugin {
             }
             break;
         case self::STRATEGY_IMPORT_AS_ACHIEVEMENT:
-            $dates = PluginImportLeap::get_leap_dates($entry);
+            $dates = PluginImportLeap::get_leap_dates($entry, $importer->get_namespaces(), $importer->get_leap2a_namespace());
             $enddate = (isset($dates['end'])) ? self::convert_leap_date_to_resume_date($dates['end']) : '';
 
             $values = array(
@@ -290,7 +292,7 @@ class LeapImportResume extends LeapImportArtefactPlugin {
             ArtefactTypeResumeComposite::ensure_composite_value($values, 'certification', $importer->get('usr'));
             break;
         case self::STRATEGY_IMPORT_AS_EMPLOYMENT:
-            $dates = PluginImportLeap::get_leap_dates($entry);
+            $dates = PluginImportLeap::get_leap_dates($entry, $importer->get_namespaces(), $importer->get_leap2a_namespace());
             $startdate = (isset($dates['start'])) ? self::convert_leap_date_to_resume_date($dates['start']) : '';
             $enddate   = (isset($dates['end']))   ? self::convert_leap_date_to_resume_date($dates['end'])   : '';
 
@@ -311,7 +313,7 @@ class LeapImportResume extends LeapImportArtefactPlugin {
             ArtefactTypeResumeComposite::ensure_composite_value($values, 'employmenthistory', $importer->get('usr'));
             break;
         case self::STRATEGY_IMPORT_AS_BOOK:
-            $dates = PluginImportLeap::get_leap_dates($entry);
+            $dates = PluginImportLeap::get_leap_dates($entry, $importer->get_namespaces(), $importer->get_leap2a_namespace());
             $enddate   = (isset($dates['end']))   ? self::convert_leap_date_to_resume_date($dates['end'])   : '';
 
             $contribution = $description = '';
@@ -320,6 +322,14 @@ class LeapImportResume extends LeapImportArtefactPlugin {
                 $contribution = $role->title;
                 $description  = PluginImportLeap::get_entry_content($role, $importer);
             }
+            // check if the import is of the version leap2a 2010-07. If it is then override the contribution and description
+            if($importer->get_leap2a_namespace() == PluginImportLeap::NS_LEAP) {
+                $myrole = PluginImportLeap::get_leap_myrole($entry, $importer->get_namespaces(), $importer->get_leap2a_namespace());
+                if($myrole) {
+                    $contribution = $myrole;
+                }
+                $description  = PluginImportLeap::get_entry_content($entry, $importer);
+            }
 
             $values = array(
                 'date' => $enddate,
@@ -331,7 +341,7 @@ class LeapImportResume extends LeapImportArtefactPlugin {
             ArtefactTypeResumeComposite::ensure_composite_value($values, 'book', $importer->get('usr'));
             break;
         case self::STRATEGY_IMPORT_AS_EDUCATION:
-            $dates = PluginImportLeap::get_leap_dates($entry);
+            $dates = PluginImportLeap::get_leap_dates($entry, $importer->get_namespaces(), $importer->get_leap2a_namespace());
             $startdate = (isset($dates['start'])) ? self::convert_leap_date_to_resume_date($dates['start']) : '';
             $enddate   = (isset($dates['end']))   ? self::convert_leap_date_to_resume_date($dates['end'])   : '';
 
@@ -364,7 +374,7 @@ class LeapImportResume extends LeapImportArtefactPlugin {
             ArtefactTypeResumeComposite::ensure_composite_value($values, 'educationhistory', $importer->get('usr'));
             break;
         case self::STRATEGY_IMPORT_AS_MEMBERSHIP:
-            $dates = PluginImportLeap::get_leap_dates($entry);
+            $dates = PluginImportLeap::get_leap_dates($entry, $importer->get_namespaces(), $importer->get_leap2a_namespace());
             $startdate = (isset($dates['start'])) ? self::convert_leap_date_to_resume_date($dates['start']) : '';
             $enddate   = (isset($dates['end']))   ? self::convert_leap_date_to_resume_date($dates['end'])   : '';
 
@@ -395,14 +405,16 @@ class LeapImportResume extends LeapImportArtefactPlugin {
             $composites = array();
 
             $person = $importer->get_entry_by_id($persondataid);
-            $persondata = $person->xpath('leap:persondata');
+            $namespaces = $importer->get_namespaces();
+            $ns = $importer->get_leap2a_namespace();
+            $persondata = $person->xpath($namespaces[$ns].':persondata');
             foreach ($persondata as $item) {
-                $leapattributes = PluginImportLeap::get_attributes($item, PluginImportLeap::NS_LEAP);
+                $leapattributes = PluginImportLeap::get_attributes($item, $ns);
 
                 if (!isset($leapattributes['field'])) {
                     // 'Field' is required
-                    // http://wiki.cetis.ac.uk/2009-03/LEAP2A_personal_data#field
-                    $importer->trace('WARNING: persondata element did not have leap:field attribute');
+                    // http://wiki.cetis.ac.uk/2009-03/Leap2A_personal_data#field
+                    $importer->trace('WARNING: persondata element did not have leap2:field attribute');
                     continue;
                 }
 
@@ -489,7 +501,11 @@ class LeapImportResume extends LeapImportArtefactPlugin {
      * @return string The ID of the organization if there is one, else an empty string
      */
     private static function check_for_supporting_organization(PluginImportLeap $importer, $link) {
-        if ($importer->curie_equals($link['rel'], PluginImportLeap::NS_LEAP, 'is_supported_by') && isset($link['href'])) {
+        if (($importer->curie_equals($link['rel'], $importer->get_leap2a_namespace(), 'supported_by') ||
+            // this is necessary for backwards compatibility. For LEAP2A 2009-03 exports the relationship
+            // value 'is_supported_by' was used instead of the correct 'supported_by'.
+            $importer->curie_equals($link['rel'], $importer->get_leap2a_namespace(), 'is_supported_by'))
+            && isset($link['href'])) {
             if ($potentialorganization = $importer->get_entry_by_id((string)$link['href'])) {
                 if (PluginImportLeap::is_rdf_type($potentialorganization, $importer, 'organization')) {
                     return (string)$link['href'];
@@ -520,7 +536,7 @@ class LeapImportResume extends LeapImportArtefactPlugin {
         $found = false;
 
         foreach ($entry->link as $link) {
-            if ($importer->curie_equals($link['rel'], PluginImportLeap::NS_LEAP, 'is_part_of') && isset($link['href'])) {
+            if ($importer->curie_equals($link['rel'], $importer->get_leap2a_namespace(), 'is_part_of') && isset($link['href'])) {
                 $href = (string)$link['href'];
                 if (isset($cache[$href])) {
                     $found = true;
@@ -537,7 +553,7 @@ class LeapImportResume extends LeapImportArtefactPlugin {
                 }
 
                 if ($found) {
-                    $leapattributes = $importer->get_attributes($link, PluginImportLeap::NS_LEAP);
+                    $leapattributes = $importer->get_attributes($link, $importer->get_leap2a_namespace());
                     $displayorder = (isset($leapattributes['display_order']) && intval($leapattributes['display_order']) > 0)
                         ? $leapattributes['display_order']
                         : '';
