@@ -222,10 +222,16 @@ class PluginExportLeap extends PluginExport {
             $this->smarty->assign('id',          'portfolio:view' . $view->get('id'));
             $this->smarty->assign('updated',     self::format_rfc3339_date(strtotime($view->get('mtime'))));
             $this->smarty->assign('created',     self::format_rfc3339_date(strtotime($view->get('ctime'))));
-            $this->smarty->assign('summarytype', 'html');
-            $this->smarty->assign('summary',     $config['description']);
-            $this->smarty->assign('contenttype', 'html');
-            $this->smarty->assign('content',     $view->build_columns());
+            $content = $config['description'];
+            if ($newcontent = self::parse_xhtmlish_content($content)) {
+                $this->smarty->assign('summarytype', 'xhtml');
+                $this->smarty->assign('summary',     $newcontent);
+            } else {
+                $this->smarty->assign('summarytype', 'text');
+                $this->smarty->assign('summary',     $content);
+            }
+            $this->smarty->assign('contenttype', 'xhtml');
+            $this->smarty->assign('content',     self::parse_xhtmlish_content($view->build_columns()));
             $this->smarty->assign('viewdata',    $config['columns']);
             $this->smarty->assign('layout',      $view->get_layout()->widths);
             $this->smarty->assign('type',        $config['type']);
@@ -253,6 +259,115 @@ class PluginExportLeap extends PluginExport {
         }
     }
 
+
+    // Some links can be determined in advance
+    private function setup_links() {
+        if (empty($this->views) || empty($this->artefacts)) {
+            return;
+        }
+
+        $viewlist = join(',', array_keys($this->views));
+        $artefactlist = join(',', array_keys($this->artefacts));
+
+        // Artefacts directly in views
+        $records = get_records_select_array(
+            'view_artefact',
+            "view IN ($viewlist) OR artefact IN ($artefactlist)"
+        );
+        if ($records) {
+            foreach ($records as &$r) {
+                $this->links->viewcontents[$r->view][$r->artefact] = 1;
+                $this->links->artefactinview[$r->artefact][$r->view] = 1;
+            }
+        }
+
+        // Artefact parent-child relationships
+        $records = get_records_select_array(
+            'artefact',
+            "parent IN ($artefactlist) AND id IN ($artefactlist)",
+            array(),
+            '',
+            'id,parent'
+        );
+        if ($records) {
+            foreach ($records as &$r) {
+                $this->links->children[$r->parent][$r->id] = 1;
+                $this->links->parent[$r->id] = $r->parent;
+            }
+        }
+
+        // Artefact-attachment relationships
+        $records = get_records_select_array(
+            'artefact_attachment',
+            "artefact IN ($artefactlist) AND attachment IN ($artefactlist)"
+        );
+        if ($records) {
+            foreach ($records as &$r) {
+                $this->links->attachments[$r->artefact][$r->attachment] = 1;
+            }
+        }
+
+        // Other leap2a relationships
+        $this->links->viewartefact = array();
+        $this->links->artefactview = array();
+        $this->links->artefactartefact = array();
+        foreach (require_artefact_plugins() as $plugin) {
+            safe_require('export', 'leap/' . $plugin->name, 'lib.php', 'require_once', true);
+        }
+        foreach (plugins_installed('artefact') as $plugin) {
+            $classname = 'LeapExportElement' . ucfirst($plugin->name);
+            if (is_callable($classname . '::setup_links')) {
+                // You must explicitly pass variables by reference when calling
+                // call_user_func, or else they get copied automatically.
+                // Using a dummy variable here to avoid the "Call time pass by reference
+                // is deprecated" warning that php displays on the screen.
+                $dummyref =& $this->links;
+                call_user_func(
+                    array($classname, 'setup_links'),
+                    $dummyref,
+                    array_keys($this->views),
+                    array_keys($this->artefacts)
+                );
+            }
+        }
+    }
+
+    public function artefact_in_view_links($artefactid) {
+        if (isset($this->links->artefactinview[$artefactid])) {
+            return array_keys($this->links->artefactinview[$artefactid]);
+        }
+    }
+
+    public function artefact_parent_link($artefactid) {
+        if (isset($this->links->parent[$artefactid])) {
+            return $this->artefacts[$this->links->parent[$artefactid]];
+        }
+    }
+
+    public function artefact_child_links($artefactid) {
+        if (isset($this->links->children[$artefactid])) {
+            return array_intersect_key($this->artefacts, $this->links->children[$artefactid]);
+        }
+    }
+
+    public function artefact_attachment_links($artefactid) {
+        if (isset($this->links->attachments[$artefactid])) {
+            return array_intersect_key($this->artefacts, $this->links->attachments[$artefactid]);
+        }
+    }
+
+    public function artefact_artefact_links($artefactid) {
+        if (isset($this->links->artefactartefact[$artefactid])) {
+            return $this->links->artefactartefact[$artefactid];
+        }
+    }
+
+    public function artefact_view_links($artefactid) {
+        if (isset($this->links->artefactview[$artefactid])) {
+            return $this->links->artefactview[$artefactid];
+        }
+    }
+
     /**
      * Looks at all blockinstance configurations, and rewrites the artefact IDs
      * found to be IDs in the generated export.
@@ -301,7 +416,7 @@ class PluginExportLeap extends PluginExport {
         foreach ($viewartefactdata as $va) {
             if ($va->view == $viewid) {
                 $links[] = (object)array(
-                    'type' => 'has_part',
+                    'type' => 'leap2:has_part',
                     'id'   => 'portfolio:artefact' . $va->artefact,
                 );
             }
@@ -384,7 +499,7 @@ class PluginExportLeap extends PluginExport {
     * @param string $filepath path to file to add
     * @param string $newname proper resulting filename
     *
-    * @return filename string use this to substitute into <content src="">
+    * @return filename string use this to pass to add_enclosure_link
     */
     public function add_attachment($filepath, $newname) {
         if (!file_exists($filepath)) {
@@ -408,6 +523,50 @@ class PluginExportLeap extends PluginExport {
         $d = format_date($date, 'strftimew3cdatetime');
         return substr($d, 0, -2) . ':' . substr($d, -2);
     }
+
+
+    /**
+     * given some content that might be html or xhtml, try to coerce it to xhtml and return it.
+     *
+     * @param string $content some html or xhtmlish content
+     *
+     * @return xhtml content or false for unmodified text content
+     */
+    public static function parse_xhtmlish_content($content) {
+        $dom = new DomDocument();
+        $topel = $dom->createElement('tmp');
+        $tmp = new DomDocument();
+        if (strpos($content, '<') === false && strpos($content, '>') === false) {
+            return false;
+        }
+        if (@$tmp->loadXML('<div>' . $content . '</div>')) {
+            $topel->setAttribute('type', 'xhtml');
+            $content = $dom->importNode($tmp->documentElement, true);
+            $content->setAttribute('xmlns', 'http://www.w3.org/1999/xhtml');
+            $topel->appendChild($content);
+            // if that fails, it could still be html
+            // DomDocument::loadHTML() parses the input as iso-8859-1 if no
+            // encoding is declared. Since we are only loading a HTML fragment
+            // there is no  encoding declared which results in garbled output
+            // since the content is actually in utf-8. To work around this
+            // we force the encoding by appending an xml declaration.
+            // see http://php.net/manual/de/domdocument.loadhtml.php#95251
+        } else if (@$tmp->loadHTML('<?xml encoding="UTF-8"><div>' . $content . '</div>')) {
+            $xpath = new DOMXpath($tmp);
+            $elements = $xpath->query('/html/body/div');
+            if ($elements->length == 1) {
+                $ourelement = $elements->item(0);
+            }
+
+            $content = $dom->importNode($ourelement, true);
+            $content->setAttribute('xmlns', 'http://www.w3.org/1999/xhtml');
+            $topel->appendChild($content);
+        } else {
+            return false; // wtf is it then?
+        }
+        $dom->appendChild($topel->firstChild);
+        return $dom->saveXML($dom->documentElement);
+    }
 }
 
 /**
@@ -478,8 +637,15 @@ class LeapExportElement {
         $this->smarty->assign('created', PluginExportLeap::format_rfc3339_date($this->artefact->get('ctime')));
         // these are the ones we really need to override
         $this->add_links();
-        $this->smarty->assign('content', $this->get_content());
-        $this->smarty->assign('contenttype', $this->get_content_type());
+        $content = $this->get_content();
+        // try to coerce it to xhtml
+        if ($this->get_content_type() != 'text' && $newcontent = PluginExportLeap::parse_xhtmlish_content($content)) {
+            $this->smarty->assign('contenttype', 'xhtml');
+            $this->smarty->assign('content', $newcontent);
+        } else {
+            $this->smarty->assign('contenttype', 'text');
+            $this->smarty->assign('content', $content);
+        }
         $this->smarty->assign('leaptype', $this->get_leap_type());
         $this->smarty->assign('author', $this->get_entry_author());
 
@@ -535,7 +701,7 @@ class LeapExportElement {
     */
     public function add_generic_link($id, $rel, $extras=null) {
         if (!in_array($rel, array('related', 'alternate', 'enclosure'))) {
-            $rel = 'leap:' . $rel;
+            $rel = 'leap2:' . $rel;
         }
         $link = array(
             'id'   => 'portfolio:' . $id,
@@ -570,6 +736,22 @@ class LeapExportElement {
         }
     }
 
+    /**
+     * add an enclosure link to the export
+     * for where we previously used the src attribute of the content tag.
+     * this does not attach the file to the expot, you have to use the
+     * {@link add_attachment} method on the exporter object.
+     *
+     * @param string $filename the relative path of the file (NOT including the filesdir)
+     */
+    public function add_enclosure_link($filename) {
+        $this->links[$filename] = (object)array(
+            'id' => $this->exporter->get('filedir') . $filename,
+            'type' => 'enclosure',
+            'file' => true
+        );
+    }
+
     /**
     * Path to main entry template.
     * this can be overridden per artefact plugin... eg
@@ -801,7 +983,7 @@ class LeapExportOutputFilter {
         $html = preg_replace_callback(
             array(
                 '#<(a[^>]+)href="(' . preg_quote(get_config('wwwroot')) . ')?/?artefact/file/download\.php\?file=(\d+)(&amp;view=\d+)?"([^>]*)>#',
-                '#<(img[^>]+)src="(' . preg_quote(get_config('wwwroot')) . ')?/?artefact/file/download\.php\?file=(\d+)(&amp;view=\d+)?"([^>]*)>#',
+                '#<(img[^>]+)src="(' . preg_quote(get_config('wwwroot')) . ')?/?artefact/file/download\.php\?file=(\d+)([^"]*)?"([^>]*)>#',
             ),
             array($this, 'replace_download_link'),
             $html
@@ -817,7 +999,7 @@ class LeapExportOutputFilter {
     private function replace_artefact_link($matches) {
         $artefactid = $matches[2];
         if (in_array($artefactid, $this->artefactids)) {
-            return '<a rel="has_part" href="portfolio:artefact' . hsc($artefactid) . '"' . $matches[5] . '>';
+            return '<a rel="leap2:has_part" href="portfolio:artefact' . hsc($artefactid) . '"' . $matches[5] . '>';
         }
 
         // If the artefact isn't in the export, then we can't provide an 
@@ -833,7 +1015,7 @@ class LeapExportOutputFilter {
     private function replace_download_link($matches) {
         $artefactid = $matches[3];
         if (in_array($artefactid, $this->artefactids)) {
-            return '<' . $matches[1] . 'rel="has_part" href="portfolio:artefact' . hsc($artefactid) . '"' . $matches[5] . '>';
+            return '<' . $matches[1] . 'rel="leap2:has_part" href="portfolio:artefact' . hsc($artefactid) . '"' . $matches[5] . ($matches[1] == 'img' ? '/' : '') . '>';
         }
 
         log_debug("Not providing an export-relative link for $artefactid");
