@@ -1,7 +1,8 @@
 <?php
 /**
  * Mahara: Electronic portfolio, weblog, resume builder and social networking
- * Copyright (C) 2006-2008 Catalyst IT Ltd (http://www.catalyst.net.nz)
+ * Copyright (C) 2006-2009 Catalyst IT Ltd and others; see:
+ *                         http://wiki.mahara.org/Contributors
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -20,7 +21,7 @@
  * @subpackage core
  * @author     Catalyst IT Ltd
  * @license    http://www.gnu.org/copyleft/gpl.html GNU GPL
- * @copyright  (C) 2006-2008 Catalyst IT Ltd http://catalyst.net.nz
+ * @copyright  (C) 2006-2009 Catalyst IT Ltd http://catalyst.net.nz
  *
  */
 
@@ -28,26 +29,23 @@ define('INTERNAL', 1);
 define('MENUITEM', 'groups/groupsiown');
 require(dirname(dirname(__FILE__)) . '/init.php');
 require_once('pieforms/pieform.php');
+require_once('group.php');
 define('TITLE', get_string('editgroup', 'group'));
 
 $id = param_integer('id');
+define('GROUP', $id);
 
-$group_data = get_record('group', 'id', $id, 'owner', $USER->get('id'), 'deleted', 0);
+$group_data = get_record_sql("SELECT g.id, g.name, g.description, g.grouptype, g.jointype, g.public, g.usersautoadded
+    FROM {group} g
+    INNER JOIN {group_member} gm ON (gm.group = g.id AND gm.member = ? AND gm.role = 'admin')
+    WHERE g.id = ?
+    AND g.deleted = 0", array($USER->get('id'), $id));
 
 if (!$group_data) {
     $SESSION->add_error_msg(get_string('canteditdontown'));
     redirect('/group/mygroups.php');
 }
 
-$joinoptions = array(
-    'invite'     => get_string('membershiptype.invite', 'group'),
-    'request'    => get_string('membershiptype.request', 'group'),
-    'open'       => get_string('membershiptype.open', 'group'),
-);
-if ($USER->can_create_controlled_groups()) {
-    $joinoptions['controlled'] = get_string('membershiptype.controlled', 'group');
-}
-
 $editgroup = pieform(array(
     'name'     => 'editgroup',
     'method'   => 'post',
@@ -67,13 +65,33 @@ $editgroup = pieform(array(
             'cols'         => 55,
             'defaultvalue' => $group_data->description,
         ),
-        'membershiptype' => array(
+        'grouptype' => array(
             'type'         => 'select',
-            'title'        => get_string('membershiptype', 'group'),
-            'options'      => $joinoptions,
-            'defaultvalue' => $group_data->jointype,
+            'title'        => get_string('grouptype', 'group'),
+            'options'      => group_get_grouptype_options($group_data->grouptype),
+            'defaultvalue' => $group_data->grouptype . '.' . $group_data->jointype,
             'help'         => true,
         ),
+        'public' => array(
+            'type'         => 'select',
+            'title'        => get_string('publiclyviewablegroup', 'group'),
+            'description'  => get_string('publiclyviewablegroupdescription', 'group'),
+            'options'      => array(true  => get_string('yes'),
+                                    false => get_string('no')),
+            'defaultvalue' => $group_data->public,
+            'help'         => true,
+            'ignore'       => !(get_config('createpublicgroups') == 'all' || get_config('createpublicgroups') == 'admins' && $USER->get('admin')),
+        ),
+        'usersautoadded' => array(
+            'type'         => 'select',
+            'title'        => get_string('usersautoadded', 'group'),
+            'description'  => get_string('usersautoaddeddescription', 'group'),
+            'options'      => array(true  => get_string('yes'),
+                                    false => get_string('no')),
+            'defaultvalue' => $group_data->usersautoadded,
+            'help'         => true,
+            'ignore'       => !$USER->get('admin'),
+        ),
         'id'          => array(
             'type'         => 'hidden',
             'value'        => $id,
@@ -86,9 +104,6 @@ $editgroup = pieform(array(
 ));
 
 function editgroup_validate(Pieform $form, $values) {
-    global $USER;
-    global $SESSION;
-
     $cid = get_field('group', 'id', 'name', $values['name']);
 
     if ($cid && $cid != $values['id']) {
@@ -101,49 +116,68 @@ function editgroup_cancel_submit() {
 }
 
 function editgroup_submit(Pieform $form, $values) {
-    global $USER;
-    global $SESSION;
+    global $USER, $SESSION, $group_data;
 
     db_begin();
 
     $now = db_format_timestamp(time());
 
+    list($grouptype, $jointype) = explode('.', $values['grouptype']);
+    $values['public'] = (isset($values['public'])) ? $values['public'] : 0;
+    $values['usersautoadded'] = (isset($values['usersautoadded'])) ? $values['usersautoadded'] : 0;
+
     update_record(
         'group',
         (object) array(
             'id'             => $values['id'],
             'name'           => $values['name'],
             'description'    => $values['description'],
-            'jointype'       => $values['membershiptype'],
+            'grouptype'      => $grouptype,
+            'jointype'       => $jointype,
             'mtime'          => $now,
+            'usersautoadded' => intval($values['usersautoadded']),
+            'public'         => intval($values['public']),
         ),
         'id'
     );
 
-    // Ensure the user is marked a tutor of the group if necessary
-    if ($values['membershiptype'] == 'controlled' && $USER->can_create_controlled_groups()) {
-        update_record(
-            'group_member',
-            (object) array(
-                'group'  => $values['id'],
-                'member' => $USER->get('id'),
-                'tutor'  => 1
-            ),
-            array('group', 'member')
-        );
+    // When jointype changes from invite/request to anything else,
+    // remove all open invitations/requests, ---
+    // Except for when jointype changes from request to open. Then
+    // we can just add group membership for everyone with an open
+    // request.
+
+    if ($group_data->jointype == 'invite' && $jointype != 'invite') {
+        delete_records('group_member_invite', 'group', $group_data->id);
+    }
+    else if ($group_data->jointype == 'request') {
+        if ($jointype == 'open') {
+            $userids = get_column_sql('
+                SELECT u.id
+                FROM {usr} u JOIN {group_member_request} r ON u.id = r.member
+                WHERE r.group = ? AND u.deleted = 0',
+                array($group_data->id)
+            );
+            if ($userids) {
+                foreach ($userids as $uid) {
+                    group_add_user($group_data->id, $uid);
+                }
+            }
+        }
+        else if ($jointype != 'request') {
+            delete_records('group_member_request', 'group', $group_data->id);
+        }
     }
 
     $SESSION->add_ok_msg(get_string('groupsaved', 'group'));
 
     db_commit();
 
-    redirect('/group/mygroups.php');
+    redirect('/group/view.php?id=' . $values['id']);
 }
 
 $smarty = smarty();
-
 $smarty->assign('editgroup', $editgroup);
-
 $smarty->display('group/edit.tpl');
 
 ?>
