@@ -48,6 +48,9 @@ class PluginImportLeap extends PluginImport {
     protected $logtargets = LOG_TARGET_ERRORLOG;
     protected $logfile = '';
     protected $profile = false;
+    protected $leap2anamespace = null;
+    protected $leap2atypenamespace = null;
+    protected $leap2acategories = null;
 
     private $snapshots = array();
 
@@ -56,9 +59,11 @@ class PluginImportLeap extends PluginImport {
 
     const NS_ATOM       = 'http://www.w3.org/2005/Atom';
     const NS_RDF        = 'http://www.w3.org/1999/02/22-rdf-syntax-ns#';
-    const NS_LEAP       = 'http://wiki.cetis.ac.uk/2009-03/LEAP2A_predicates#';
-    const NS_LEAPTYPE   = 'http://wiki.cetis.ac.uk/2009-03/LEAP2A_types#';
-    const NS_CATEGORIES = 'http://wiki.cetis.ac.uk/2009-03/LEAP2A_categories/';
+    const NS_LEAP_200903       = 'http://wiki.cetis.ac.uk/2009-03/LEAP2A_predicates#';
+    const NS_LEAPTYPE_200903   = 'http://wiki.cetis.ac.uk/2009-03/LEAP2A_types#';
+    const NS_CATEGORIES_200903 = 'http://wiki.cetis.ac.uk/2009-03/LEAP2A_categories/';
+    const NS_LEAP              = 'http://terms.leapspecs.org/';
+    const NS_CATEGORIES        = 'http://wiki.leapspecs.org/2A/categories/';
     const NS_MAHARA     = 'http://wiki.mahara.org/Developer_Area/Import%2F%2FExport/LEAP_Extensions#';
 
     const XHTML_DIV       = '<div xmlns="http://www.w3.org/1999/xhtml">';
@@ -97,6 +102,8 @@ class PluginImportLeap extends PluginImport {
         $this->trace("Document loaded, entries: " . count($this->xml->entry));
         $this->snapshot('loaded XML');
 
+        $this->detect_leap2a_namespace();
+
         $this->ensure_document_valid();
 
         $this->create_strategy_listing();
@@ -110,6 +117,28 @@ class PluginImportLeap extends PluginImport {
         db_commit();
     }
 
+    /**
+     * detect the leap2a namespace of the import document by looking for the 'version' element
+     *
+     *
+     */
+    private function detect_leap2a_namespace () {
+        // check for the leap2a version used
+        $leap2 = false;
+        if(in_array('leap2', $this->namespaces)) {
+            $leap2 = true;
+        }
+        if($leap2) {
+            $this->leap2anamespace = self::NS_LEAP;
+            $this->leap2atypenamespace = self::NS_LEAP;
+            $this->leap2acategories = self::NS_CATEGORIES;
+        } else {
+            $this->leap2anamespace = self::NS_LEAP_200903;
+            $this->leap2atypenamespace = self::NS_LEAPTYPE_200903;
+            $this->leap2acategories = self::NS_CATEGORIES_200903;
+        }
+    }
+
     private function ensure_document_valid() {
         // TODO: http://wiki.mahara.org/Developer_Area/Import%2f%2fExport/Import%3a_Implementation_Plan#beginning
         //
@@ -126,7 +155,12 @@ class PluginImportLeap extends PluginImport {
 
         // Check all the namespaces we're gonna need are declared, and warn if 
         // they're not there
-        foreach (array(self::NS_ATOM, self::NS_RDF, self::NS_LEAP, self::NS_LEAPTYPE, self::NS_CATEGORIES) as $ns) {
+        if($this->leap2anamespace == self::NS_LEAP) {
+            $namespaces = array(self::NS_ATOM, self::NS_RDF, self::NS_LEAP, self::NS_CATEGORIES);
+        } else {
+            $namespaces = array(self::NS_ATOM, self::NS_RDF, self::NS_LEAP_200903, self::NS_LEAPTYPE_200903, self::NS_CATEGORIES_200903);
+        }
+        foreach ($namespaces as $ns) {
             if (!isset($this->namespaces[$ns])) {
                 $this->trace("WARNING: Namespaces $ns wasn't declared - this will make importing data correctly difficult");
             }
@@ -146,6 +180,7 @@ class PluginImportLeap extends PluginImport {
             if (safe_require('import', 'leap/' . $plugin, 'lib.php', 'require_once', true)) {
                 $classname = 'LeapImport' . ucfirst($plugin);
                 if (method_exists($classname, 'setup')) {
+                    safe_require('artefact', $plugin);
                     call_static_method($classname, 'setup', $this);
                 }
             }
@@ -162,7 +197,7 @@ class PluginImportLeap extends PluginImport {
             }
             else {
                 $persondata = $this->get('xml')->xpath('//a:feed/a:entry/a:category[('
-                    . $this->curie_xpath('@scheme', PluginImportLeap::NS_CATEGORIES, 'person_type#') . ') and @term="Self"]/../a:id');
+                    . $this->curie_xpath('@scheme', $this->get_categories_namespace(), 'person_type#') . ') and @term="Self"]/../a:id');
                 if (isset($persondata[0])) {
                     $this->persondataid = (string)$persondata[0][0];
                 }
@@ -349,7 +384,7 @@ class PluginImportLeap extends PluginImport {
                 throw new SystemException("import_from_load_mapping(): $classname::import_using_strategy has not return a list");
             }
 
-            $this->artefactids = array_merge($this->artefactids, $artefactmapping);
+            $this->artefactids = array_merge_recursive($this->artefactids, $artefactmapping);
 
             $usedlist[] = $entryid;
             if (isset($strategydata['other_required_entries'])) {
@@ -378,11 +413,15 @@ class PluginImportLeap extends PluginImport {
             $strategydata = $this->loadmapping[$entryid];
             $classname = 'LeapImport' . ucfirst($strategydata['artefactplugin']);
             $entry = $this->get_entry_by_id($entryid);
-            call_static_method($classname, 'setup_relationships',
+            $maybeartefacts = call_static_method($classname, 'setup_relationships',
                 $entry, $this, $strategydata['strategy'], $strategydata['other_required_entries']);
+            if (is_array($maybeartefacts)) { // some might add new artefacts (eg files attached by relpath, rather than leap id)
+                $this->artefactids = array_merge_recursive($this->artefactids, $maybeartefacts);
+            }
         }
 
         // Fix up any artefact references in the content of imported artefacts
+        // TODO: restrict this to the ones that were imported right now
         if ($artefacts = get_records_array('artefact', 'owner', $this->get('usr'), '', 'id, title, description')) {
             foreach ($artefacts as $artefact) {
                 $this->fix_artefact_references($artefact);
@@ -791,7 +830,9 @@ class PluginImportLeap extends PluginImport {
      * @return boolean Whether it's worth checking in more detail
      */
     private function artefact_reference_quickcheck($field) {
-        return (false !== strpos($field, 'rel="has_part"'))
+
+        return (false !== strpos($field, 'rel="'.$this->leap2anamespace.':has_part"')
+                || false !== strpos($field, 'rel="enclosure"'))
             && (
                 (false !== strpos($field, '<img'))
                 || (false !== strpos($field, '<a'))
@@ -805,7 +846,7 @@ class PluginImportLeap extends PluginImport {
      * @return string The fixed field
      */
     private function fix_artefact_reference($field) {
-        $match = '#<((img)|a)([^>]+)rel="has_part" href="portfolio:artefact([\d]+)"([^>]*)>#';
+        $match = '#<((img)|a)([^>]+)rel="(?:'.$this->leap2anamespace.':has_part|enclosure)" (?:src|href)="([^"]+)"([^>]*)>#';
         $field = preg_replace_callback($match,
             array($this, '_fixref'),
             $field);
@@ -818,11 +859,11 @@ class PluginImportLeap extends PluginImport {
             $basepath = get_mahara_install_subdirectory();
         }
 
-        $artefacts = $this->get_artefactids_imported_by_entryid('portfolio:artefact' . $matches[4]);
+        $artefacts = $this->get_artefactids_imported_by_entryid($matches[4]);
         if (is_null($artefacts) || count($artefacts) != 1) {
             // This can happen if a leap2a xml file is uploaded that refers to
             // files that (naturally) weren't uploaded with it.
-            log_debug("Warning: fixref was expecting one artefact to have been imported by entry portfolio:artefact{$matches[4]} but seems to have gotten " . count($artefacts));
+            log_debug("Warning: fixref was expecting one artefact to have been imported by entry {$matches[4]} but seems to have gotten " . count($artefacts));
             return $matches[0];
         }
         return '<' . $matches[1] . $matches[3] . ($matches[1] == 'img' ? 'src' : 'href') . '="'
@@ -925,7 +966,7 @@ class PluginImportLeap extends PluginImport {
      */
     public static function is_rdf_type(SimpleXMLElement $entry, PluginImportLeap $importer, $rdftype) {
         $result = $entry->xpath('rdf:type['
-            . $importer->curie_xpath('@rdf:resource', PluginImportLeap::NS_LEAPTYPE, $rdftype) . ']');
+            . $importer->curie_xpath('@rdf:resource', $importer->get_leaptype_namespace(), $rdftype) . ']');
         return isset($result[0]) && $result[0] instanceof SimpleXMLElement;
     }
 
@@ -940,7 +981,7 @@ class PluginImportLeap extends PluginImport {
      */
     public static function is_correct_category_scheme(SimpleXMLElement $entry, PluginImportLeap $importer, $category, $term) {
         $result = $entry->xpath('a:category[('
-            . $importer->curie_xpath('@scheme', PluginImportLeap::NS_CATEGORIES, $category . '#') . ') and @term="' . $term . '"]');
+            . $importer->curie_xpath('@scheme', $importer->get_categories_namespace(), $category . '#') . ') and @term="' . $term . '"]');
         return isset($result[0]) && $result[0] instanceof SimpleXMLElement;
     }
 
@@ -984,7 +1025,7 @@ class PluginImportLeap extends PluginImport {
         case 'text':
             return (string)$entry->content;
         default:
-            throw new SystemException("Unrecognised content type for entry '$entry->id'");
+            throw new SystemException("Unrecognised content type for entry '$entry->id' ($type)");
         }
     }
 
@@ -1004,9 +1045,14 @@ class PluginImportLeap extends PluginImport {
     }
 
     /**
-     * Look for leap:date elements that are part of an entry (if any) and 
+     * Look for leap2:date elements that are part of an entry (if any) and 
      * return the values we parse from them
      *
+     *
+     * @param SimpleXMLElement $entry The element containing the date
+     * @param array $namespaces array of namespaces @see PluginImportLeap::namespaces
+     * @param string $ns namespace URL which is used as a key in the $namespaces array
+     *
      * Returned in a structure like so:
      * array(
      *     'start' => array(
@@ -1032,10 +1078,10 @@ class PluginImportLeap extends PluginImport {
      *
      * Spec reference: http://wiki.cetis.ac.uk/2009-03/LEAP2A_literals#date
      */
-    public static function get_leap_dates(SimpleXMLElement $entry) {
+    public static function get_leap_dates(SimpleXMLElement $entry, $namespaces, $ns) {
         $dates = array();
         foreach (array('start', 'end', 'target') as $point) {
-            $dateelement = $entry->xpath('leap:date[@leap:point="' . $point . '"]');
+            $dateelement = $entry->xpath($namespaces[$ns].':date[@'.$namespaces[$ns].':point="' . $point . '"]');
             if (count($dateelement) == 1) {
                 $dateelement = $dateelement[0];
             }
@@ -1046,9 +1092,9 @@ class PluginImportLeap extends PluginImport {
                     $dates[$point]['value'] = $date;
                 }
 
-                // Parse for leap:label
+                // Parse for leap2:label
                 $leapattributes = array();
-                foreach ($dateelement->attributes(PluginImportLeap::NS_LEAP) as $key => $value) {
+                foreach ($dateelement->attributes($ns) as $key => $value) {
                     $leapattributes[$key] = (string)$value;
                 }
                 if (isset($leapattributes['label'])) {
@@ -1059,6 +1105,28 @@ class PluginImportLeap extends PluginImport {
         return $dates;
     }
 
+    /**
+     * Look for a leap2:myrole element that is part of an entry (if any) and
+     * return the value
+     *
+     *
+     * @param SimpleXMLElement $entry The element containing the date
+     * @param array $namespaces array of namespaces @see PluginImportLeap::namespaces
+     * @param string $ns namespace URL which is used as a key in the $namespaces array
+     *
+     * @return string
+     *
+     * Spec reference: http://wiki.leapspecs.org/2A/literals#myrole
+     */
+    public static function get_leap_myrole(SimpleXMLElement $entry, $namespaces, $ns) {
+        $myrole = $entry->xpath($namespaces[$ns].':myrole');
+        // we only expect one role
+        if($myrole[0]) {
+            return $myrole[0];
+        }
+        return '';
+    }
+
     /**
      * Waffer thin helper to grab all attributes in a namespace.
      *
@@ -1077,6 +1145,101 @@ class PluginImportLeap extends PluginImport {
         return $attributes;
     }
 
+    /**
+     * getter to return the leap2typeanamespace property
+     *
+     * @return string namespace URL
+     */
+    public function get_leaptype_namespace() {
+        return $this->leap2atypenamespace;
+    }
+
+    /**
+     * getter to return the leap2anamespace property
+     *
+     * @return string namespace URL
+     */
+    public function get_leap2a_namespace() {
+        return $this->leap2anamespace;
+    }
+
+    /**
+     * getter to return the namespace property
+     *
+     * @return array
+     */
+    public function get_namespaces() {
+        return $this->namespaces;
+    }
+
+    /**
+     * getter to return the leap2 categories namespace
+     *
+     * @return string namespace URL
+     */
+    public function get_categories_namespace() {
+        return $this->leap2acategories;
+    }
+
+    /**
+     * helper function to create attachments between entries.
+     * The 2010-07 version of leap2a says that linked *entries* should use related relation,
+     * and directly linked files (attachments) should use enclosures.
+     * However, for BC we should support both.
+     * This function supports both and additionally creates the File artefacts for attachments, then links them.
+     *
+     * @param SimpleXMLElement $entry    the entry we want to attach things *to*
+     * @param SimpleXMLElement $link     the link to inspect
+     * @param ArtefactType     $artefact the artefact that has been created from the entry.
+     *
+     * @return void|int the id of a *newly created* attached artefact
+     */
+    public function create_attachment(SimpleXMLElement $entry, SimpleXMLElement $link, ArtefactType $artefact) {
+        if (($this->curie_equals($link['rel'], '', 'enclosure') || $this->curie_equals($link['rel'], '', 'related')) && isset($link['href'])) {
+            $this->trace("Attaching file $link[href] to comment $entry->id", PluginImportLeap::LOG_LEVEL_VERBOSE);
+            $artefactids = $this->get_artefactids_imported_by_entryid((string)$link['href']);
+            if (isset($artefactids[0])) {
+                $artefact->attach($artefactids[0]);
+            } else { // it may be just an attached file, with no Leap2A element in its own right ....
+                if ($id = $this->create_linked_file($entry, $link)) {
+                    $artefact->attach($id);
+
+                    return $id;
+                }
+            }
+        }
+    }
+
+    /**
+     * Attaches a file to a blogpost entry that was just linked directly, rather than having a Leap2a entry
+     * See http://wiki.leapspecs.org/2A/files
+     *
+     * @param SimpleXMLElement $entry
+     * @param SimpleXMLElement $link
+     */
+    private function create_linked_file(SimpleXMLElement $entry, SimpleXMLElement $link) {
+        $this->trace($link);
+        $pathname = urldecode((string)$link['href']);
+        $data = $this->get('data');
+        $dir = dirname($data['filename']);
+        $pathname = $dir . DIRECTORY_SEPARATOR . $pathname;
+        if (!file_exists($pathname)) {
+            return false;
+        }
+        // Note: this data is passed (eventually) to ArtefactType->__construct,
+        // which calls strtotime on the dates for us
+        require_once('file.php');
+        $data = (object)array(
+            'title' => (string)$entry->title . ' ' . get_string('attachment'),
+            'owner' => $this->get('usr'),
+            'filetype' => file_mime_type($pathname),
+        );
+        return ArtefactTypeFile::save_file($pathname, $data, $this->get('usrobj'), true);
+    }
+
+    public function entry_exists($entryid) {
+        return array_key_exists($entryid, $this->strategylisting);
+    }
 }
 
 
