@@ -1,7 +1,8 @@
 <?php
 /**
  * Mahara: Electronic portfolio, weblog, resume builder and social networking
- * Copyright (C) 2006-2008 Catalyst IT Ltd (http://www.catalyst.net.nz)
+ * Copyright (C) 2006-2009 Catalyst IT Ltd and others; see:
+ *                         http://wiki.mahara.org/Contributors
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -20,16 +21,17 @@
  * @subpackage lang
  * @author     Catalyst IT Ltd
  * @license    http://www.gnu.org/copyleft/gpl.html GNU GPL
- * @copyright  (C) 2006-2008 Catalyst IT Ltd http://catalyst.net.nz
+ * @copyright  (C) 2006-2009 Catalyst IT Ltd http://catalyst.net.nz
  *
  */
 
 defined('INTERNAL') || die();
 
 $string['createview']             = 'Create View';
-$string['createviewstepone']      = 'Create View Step One: Details';
-$string['createviewsteptwo']      = 'Create View Step Two: Layout';
+$string['createviewstepone']      = 'Create View Step One: Layout';
+$string['createviewsteptwo']      = 'Create View Step Two: Details';
 $string['createviewstepthree']    = 'Create View Step Three: Access';
+$string['createtemplate']         = 'Create Template';
 $string['editviewdetails']        = 'Edit Details for View "%s"';
 $string['editblocksforview']      = 'Edit View "%s"';
 $string['editaccessforview']      = 'Edit Access for View "%s"';
@@ -40,13 +42,18 @@ $string['description']            = 'View Description';
 $string['startdate']              = 'Access Start Date/Time';
 $string['stopdate']               = 'Access End Date/Time';
 $string['startdatemustbebeforestopdate'] = 'The start date must be before the stop date';
+$string['unrecogniseddateformat'] = 'Unrecognised date format';
 $string['ownerformat']            = 'Name display format';
 $string['ownerformatdescription'] = 'How do you want people who look at your View to see your name?';
+$string['profileviewtitle']       = 'Profile view';
+$string['editprofileview']        = 'Edit profile view';
 
 // my views
 $string['artefacts'] = 'Artefacts';
 $string['myviews'] = 'My Views';
-$string['reallyaddaccesstoemptyview'] = 'Your View contains no artefacts.  Do you really want to give these users access to the View?';
+$string['groupviews'] = 'Group Views';
+$string['institutionviews'] = 'Institution Views';
+$string['reallyaddaccesstoemptyview'] = 'Your View contains no blocks.  Do you really want to give these users access to the View?';
 $string['viewdeleted'] = 'View deleted';
 $string['viewsubmitted'] = 'View submitted';
 $string['editviewnameanddescription'] = 'Edit View details';
@@ -54,18 +61,25 @@ $string['editviewaccess'] = 'Edit View access';
 $string['deletethisview'] = 'Delete this View';
 $string['submitthisviewto'] = 'Submit this View to';
 $string['forassessment'] = 'for assessment';
-$string['accessfromdate'] = 'Nobody can see this View before %s';
-$string['accessuntildate'] = 'Nobody can see this View after %s';
-$string['accessbetweendates'] = 'Nobody can see this View before %s or after %s';
+$string['accessfromdate2'] = 'Nobody else can see this View before %s';
+$string['accessuntildate2'] = 'Nobody else can see this View after %s';
+$string['accessbetweendates2'] = 'Nobody else can see this View before %s or after %s';
 $string['artefactsinthisview'] = 'Artefacts in this View';
 $string['whocanseethisview'] = 'Who can see this View';
 $string['view'] = 'view';
 $string['views'] = 'views';
 $string['View'] = 'View';
 $string['Views'] = 'Views';
-$string['viewsubmittedtogroup'] = 'This View has been submitted to <a href="' . get_config('wwwroot') . 'group/view.php?id=%s">%s</a>';
-$string['nobodycanseethisview'] = 'Nobody can see this View';
-$string['noviews'] = 'You have no Views.';
+$string['viewsubmittedtogroup'] = 'This View has been submitted to <a href="%s">%s</a>';
+$string['nobodycanseethisview2'] = 'Only you can see this View';
+$string['noviews'] = 'No Views.';
+$string['youhavenoviews'] = 'You have no Views.';
+$string['youhaveoneview'] = 'You have 1 View.';
+$string['youhaveviews']   = 'You have %s Views.';
+$string['viewsownedbygroup'] = 'Views owned by this group';
+$string['viewssharedtogroup'] = 'Views shared to this group';
+$string['viewssharedtogroupbyothers'] = 'Views shared to this group by others';
+$string['viewssubmittedtogroup'] = 'Views submitted to this group';
 
 // access levels
 $string['public'] = 'Public';
@@ -78,6 +92,8 @@ $string['grouplower'] = 'group';
 $string['tutors'] = 'tutors';
 $string['loggedinlower'] = 'logged in users';
 $string['publiclower'] = 'public';
+$string['everyoneingroup'] = 'Everyone in Group';
+$string['token'] = 'Secret URL';
 
 // view user
 $string['inviteusertojoingroup'] = 'Invite this user to join a group';
@@ -106,6 +122,7 @@ $string['makepublic'] = 'Make public';
 $string['nopublicfeedback'] = 'No public feedback';
 $string['notifysiteadministrator'] = 'Notify site administrator';
 $string['placefeedback'] = 'Place feedback';
+$string['placefeedbacknotallowed'] = 'You are not allowed to place feedback on this View';
 $string['print'] = 'Print';
 $string['thisfeedbackispublic'] = 'This feedback is public';
 $string['thisfeedbackisprivate'] = 'This feedback is private';
@@ -134,6 +151,7 @@ $string['deletespecifiedview'] = 'Delete View "%s"';
 $string['deleteviewconfirm'] = 'Do you really want to delete this View? It cannot be undone.';
 
 $string['editaccesspagedescription2'] = '<p>By default, only you can see your View. Here you can choose who else you would like to be able to see the information in your View. Click Add to grant access to Public, Logged in Users or Friends. Use the search box to add individual Users or Groups. All those added will appear in the right hand pane, under Added.</p>
+<p>You can also give other users permission to copy your View into their own portfolios.  When users copy a View, they will automatically get their own copies all of the files and folders within it.</p>
 <p>Once you are done, scroll down and click Save to continue.</p>';
 
 $string['overridingstartstopdate'] = 'Overriding Start/Stop Dates';
@@ -146,7 +164,7 @@ $string['viewinformationsaved'] = 'View information saved successfully';
 
 $string['canteditdontown'] = 'You can\'t edit this View because you don\'t own it';
 $string['canteditdontownfeedback'] = 'You can\'t edit this feedback because you don\'t own it';
-$string['canteditsubmitted'] = 'You can\'t edit this View because it has been submitted for assessment to group "%s". You will have to wait until a tutor releases your view.';
+$string['canteditsubmitted'] = 'You can\'t edit this View because it has been submitted for assessment to "%s". You will have to wait until a tutor releases your view.';
 $string['feedbackchangedtoprivate'] = 'Feedback changed to private';
 
 $string['addtutors'] = 'Add Tutors';
@@ -184,13 +202,21 @@ $string['blocksinstructionajax'] = 'Drag blocks below this line to add them to y
 $string['addnewblockhere'] = 'Add new block here';
 $string['add'] = 'Add';
 $string['addcolumn'] = 'Add Column';
+$string['remove'] = 'Remove';
 $string['removecolumn'] = 'Remove this column';
-$string['moveblockleft'] = 'Move this block left';
-$string['moveblockdown'] = 'Move this block down';
-$string['moveblockup'] = 'Move this block up';
-$string['moveblockright'] = 'Move this block right';
-$string['configureblock'] = 'Configure this block';
-$string['removeblock'] = 'Remove this block';
+$string['moveblockleft'] = "Move %s block left";
+$string['movethisblockleft'] = "Move this block left";
+$string['moveblockdown'] = "Move %s block down";
+$string['movethisblockdown'] = "Move this block down";
+$string['moveblockup'] = "Move %s block up";
+$string['movethisblockup'] = "Move this block up";
+$string['moveblockright'] = "Move %s block right";
+$string['movethisblockright'] = "Move this block right";
+$string['Configure'] = 'Configure';
+$string['configureblock'] = 'Configure %s block';
+$string['configurethisblock'] = 'Configure this block';
+$string['removeblock'] = 'Remove %s block';
+$string['removethisblock'] = 'Remove this block';
 $string['blocktitle'] = 'Block Title';
 
 $string['changemyviewlayout'] = 'Change My View Layout';
@@ -227,5 +253,54 @@ $string['Search'] = 'Search';
 $string['noartefactstochoosefrom'] = 'Sorry, no artefacts to choose from';
 
 $string['access'] = 'Access';
+$string['noaccesstoview'] = 'You do not have permission to access this view';
+
+// Templates
+$string['Template'] = 'Template';
+$string['allowcopying'] = 'Allow copying';
+$string['templatedescription'] = 'Check this box if you would like the people who can see your view to be able to make their own copies of it.';
+$string['choosetemplatepagedescription'] = '<p>Here you can search through the Views that you are allowed to copy as a starting point for making a new View. You can see a preview of each View by clicking on its name. Once you have found the View you wish to copy, click the corresponding "Copy View" button to make a copy and begin customising it.</p>';
+$string['choosetemplategrouppagedescription'] = '<p>Here you can search through the Views that this group is allowed to copy as a starting point for making a new View. You can see a preview of each View by clicking on its name. Once you have found the View you wish to copy, click the corresponding "Copy View" button to make a copy and begin customising it.</p><p><strong>Note:</strong> Groups cannot currently make copies of Blogs or Blog Posts.</p>';
+$string['choosetemplateinstitutionpagedescription'] = '<p>Here you can search through the Views that this institution is allowed to copy as a starting point for making a new View. You can see a preview of each View by clicking on its name. Once you have found the View you wish to copy, click the corresponding "Copy View" button to make a copy and begin customising it.</p><p><strong>Note:</strong> Institutions cannot currently make copies of Blogs or Blog Posts.</p>';
+$string['copiedblocksandartefactsfromtemplate'] = 'Copied %d blocks and %d artefacts from %s';
+$string['filescopiedfromviewtemplate'] = 'Files copied from %s';
+$string['viewfilesdirname'] = 'viewfiles';
+$string['viewfilesdirdesc'] = 'Files from copied views';
+$string['thisviewmaybecopied'] = 'Copying is allowed';
+$string['copythisview'] = 'Copy this View';
+$string['copyview'] = 'Copy View';
+$string['createemptyview'] = 'Create Empty View';
+$string['copyaview'] = 'Copy a View';
+$string['Untitled'] = 'Untitled';
+$string['copyfornewusers'] = 'Copy for new users';
+$string['copyfornewusersdescription'] = 'Whenever a new user is created, automatically make a personal copy of this View in the user\'s portfolio.';
+$string['copyfornewmembers'] = 'Copy for new institution members';
+$string['copyfornewmembersdescription'] = 'Automatically make a personal copy of this View for all new members of %s.';
+$string['copyfornewgroups'] = 'Copy for new groups';
+$string['copyfornewgroupsdescription'] = 'Make a copy of this view in all new groups with these Group Types:';
+$string['searchviews'] = 'Search views';
+$string['searchowners'] = 'Search owners';
+$string['owner'] = 'owner';
+$string['Owner'] = 'Owner';
+$string['owners'] = 'owners';
+$string['show'] = 'Show';
+$string['searchviewsbyowner'] = 'Search for Views by owner:';
+$string['selectaviewtocopy'] = 'Select the View you wish to copy:';
+$string['listviews'] = 'List Views';
+$string['nocopyableviewsfound'] = 'No Views that you can copy';
+$string['noownersfound'] = 'No owners found';
+$string['viewsby'] = 'Views by %s';
+$string['Preview'] = 'Preview';
+$string['viewscopiedfornewusersmustbecopyable'] = 'You must allow copying before you can set a view to be copied for new users.';
+$string['viewscopiedfornewgroupsmustbecopyable'] = 'You must allow copying before you can set a view to be copied for new groups.';
+$string['copynewusergroupneedsloggedinaccess'] = 'Views copied for new users or groups must give access to logged-in users.';
+$string['viewcopywouldexceedquota'] = 'Copying this View would exceed your file quota.';
+
+$string['blockcopypermission'] = 'Block copy permission';
+$string['blockcopypermissiondesc'] = 'If you allow other users to copy this View, you may choose how this block will be copied';
+
+// Feedback list
+$string['comment'] = 'comment';
+$string['comments'] = 'comments';
 
 ?>
