@@ -1,7 +1,8 @@
 <?php // $Id: ddllib.php,v 1.42 2006/10/09 22:28:22 stronk7 Exp $
 /**
  * Mahara: Electronic portfolio, weblog, resume builder and social networking
- * Copyright (C) 2006-2008 Catalyst IT Ltd (http://www.catalyst.net.nz)
+ * Copyright (C) 2006-2009 Catalyst IT Ltd and others; see:
+ *                         http://wiki.mahara.org/Contributors
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -18,7 +19,7 @@
  *
  * @package mahara
  * @subpackage core
- * @copyright  (C) 2006-2008 Catalyst IT Ltd http://catalyst.net.nz
+ * @copyright  (C) 2006-2009 Catalyst IT Ltd http://catalyst.net.nz
  *
  * This file incorporates work covered by the following copyright and
  * permission notice:
@@ -43,14 +44,9 @@
  */
 
 // Mahara hacks
+global $CFG;
 $CFG->libdir = get_config('libroot');
 $CFG->prefix = (isset($CFG->dbprefix)) ? $CFG->dbprefix : '';
-if (is_postgres()) {
-    $CFG->dbtype = 'postgres7';
-}
-else if (is_mysql()) {
-    $CFG->dbtype = 'mysql';
-}
 // Mahara hacks end
 
 
@@ -553,12 +549,12 @@ function install_from_xmldb_file($file) {
     $xmldb_file = new XMLDBFile($file);
 
     if (!$xmldb_file->fileExists()) {
-        return false;
+        throw new InstallationException($xmldb_file->path . " doesn't exist.");
     }
 
     $loaded = $xmldb_file->loadXMLStructure();
     if (!$loaded || !$xmldb_file->isLoaded()) {
-        return false;
+        throw new InstallationException("Could not load " . $xmldb_file->path);
     }
 
     $structure = $xmldb_file->getStructure();
@@ -567,8 +563,12 @@ function install_from_xmldb_file($file) {
         return true; //Empty array = nothing to do = no error
     }
 
-    $status = $status && execute_sql_arr($sqlarr);
-    return $status;
+    if (!execute_sql_arr($sqlarr)) {
+        log_debug($sqlarr);
+        throw new SQLException("Failed to install (check logs for xmldb errors)");
+    }
+
+    return true;
 }
 
 /**
