@@ -1,7 +1,8 @@
 <?php
 /**
  * Mahara: Electronic portfolio, weblog, resume builder and social networking
- * Copyright (C) 2006-2008 Catalyst IT Ltd (http://www.catalyst.net.nz)
+ * Copyright (C) 2006-2009 Catalyst IT Ltd and others; see:
+ *                         http://wiki.mahara.org/Contributors
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -20,7 +21,7 @@
  * @subpackage auth-internal
  * @author     Catalyst IT Ltd
  * @license    http://www.gnu.org/copyleft/gpl.html GNU GPL
- * @copyright  (C) 2006-2008 Catalyst IT Ltd http://catalyst.net.nz
+ * @copyright  (C) 2006-2009 Catalyst IT Ltd http://catalyst.net.nz
  *
  */
 
@@ -121,7 +122,7 @@ class Institution {
     function findByWwwroot($wwwroot) {
 
         if (!is_string($wwwroot) || strlen($wwwroot) < 1 || strlen($wwwroot) > 255) {
-            throw new SystemException();
+            throw new SystemException('Invalid wwwroot: ' . $wwwroot);
         }
 
         $this->hostset = new HostSet();
@@ -215,6 +216,7 @@ class Institution {
     }
 
     public function addUserAsMember($user) {
+        global $USER;
         if ($this->isFull()) {
             throw new SystemException('Trying to add a user to an institution that already has a full quota of members');
         }
@@ -259,6 +261,12 @@ class Institution {
         }
         insert_record('usr_institution', $userinst);
         delete_records('usr_institution_request', 'usr', $userinst->usr, 'institution', $this->name);
+        // Copy institution views to the user's portfolio
+        $checkviewaccess = empty($user->newuser) && !$USER->get('admin');
+        $userobj = new User();
+        $userobj->find_by_id($user->id);
+        $userobj->copy_views(get_column('view', 'id', 'institution', $this->name, 'copynewuser', 1), $checkviewaccess);
+        require_once('activity.php');
         activity_occurred('maharamessage', $message);
         handle_event('updateuser', $userinst->usr);
         db_commit();
@@ -285,6 +293,7 @@ class Institution {
                 delete_records('usr_institution_request', 'usr', $user->id);
             }
             insert_record('usr_institution_request', $request);
+            require_once('activity.php');
             activity_occurred('institutionmessage', $message);
             handle_event('updateuser', $user->id);
             db_commit();
@@ -303,6 +312,7 @@ class Institution {
         db_begin();
         delete_records('usr_institution_request', 'usr', $userid, 'institution', $this->name,
                        'confirmedusr', 1);
+        require_once('activity.php');
         activity_occurred('maharamessage', $message);
         handle_event('updateuser', $userid);
         db_commit();
@@ -317,6 +327,7 @@ class Institution {
             'confirmedinstitution' => 1,
             'ctime' => db_format_timestamp(time())
         ));
+        require_once('activity.php');
         activity_occurred('institutionmessage', (object) array(
             'messagetype' => 'invite',
             'users' => array($userid),
@@ -355,7 +366,7 @@ class Institution {
         $oldauth = $user->authinstance;
         if (isset($authinstances[$oldauth]) && $authinstances[$oldauth]->institution == $this->name) {
             foreach ($authinstances as $ai) {
-                if ($ai->instancename == 'internal' && $ai->institution == 'mahara') {
+                if ($ai->authname == 'internal' && $ai->institution == 'mahara') {
                     $user->authinstance = $ai->id;
                     break;
                 }
@@ -392,8 +403,8 @@ class Institution {
             $fullname = display_name($user, null, true);
             email_user($user, null,
                 get_string('noinstitutionsetpassemailsubject', 'mahara', $sitename, $this->displayname),
-                get_string('noinstitutionsetpassemailmessagetext', 'mahara', $fullname, $this->displayname, $sitename, $user->username, $pwrequest->key, $sitename, $pwrequest->key),
-                get_string('noinstitutionsetpassemailmessagehtml', 'mahara', $fullname, $this->displayname, $sitename, $user->username, $pwrequest->key, $pwrequest->key, $sitename, $pwrequest->key, $pwrequest->key));
+                get_string('noinstitutionsetpassemailmessagetext', 'mahara', $fullname, $this->displayname, $sitename, $user->username, get_config('wwwroot'), $pwrequest->key, get_config('wwwroot'), $sitename, get_config('wwwroot'), $pwrequest->key),
+                get_string('noinstitutionsetpassemailmessagehtml', 'mahara', $fullname, $this->displayname, $sitename, $user->username, get_config('wwwroot'), $pwrequest->key, get_config('wwwroot'), $pwrequest->key, get_config('wwwroot'), $sitename, get_config('wwwroot'), $pwrequest->key, get_config('wwwroot'), $pwrequest->key));
             insert_record('usr_password_request', $pwrequest);
         }
         catch (SQLException $e) {
@@ -467,14 +478,13 @@ function get_institution_selector($includedefault = true) {
 
 /* The institution selector does exactly the same thing in both
    institutionadmins.php and institutionstaff.php (in /admin/users/).
-   This function creates the form for the page, setting
-   $institutionselector and $INLINEJAVASCRIPT in the smarty object. */
-function add_institution_selector_to_page(&$smarty, $institution, $page) {
+   This function creates the form for the page. */
+function institution_selector_for_page($institution, $page) {
     require_once('pieforms/pieform.php');
     $institutionelement = get_institution_selector(false);
 
     if (empty($institutionelement)) {
-        return false;
+        return array('institution' => false, 'institutionselector' => null, 'institutionselectorjs' => '');
     }
 
     global $USER;
@@ -507,9 +517,10 @@ addLoadEvent(function() {
 });
 EOF;
     
-    $smarty->assign('institutionselector', $institutionselector);
-    $smarty->assign('INLINEJAVASCRIPT', $js);
-
-    return $institution;
+    return array(
+        'institution'           => $institution,
+        'institutionselector'   => $institutionselector,
+        'institutionselectorjs' => $js
+    );
 }
 ?>
