@@ -34,7 +34,7 @@
  *                           the address.
  */
 function pieform_rule_integer(Pieform $form, $value, $element) {/*{{{*/
-    if (!is_numeric($value) || $value != (int)$value) {
+    if (!is_numeric($value) || floor($value) != $value) {
         return $form->i18n('rule', 'integer', 'integer', $element);
     }
 }/*}}}*/
@@ -56,6 +56,15 @@ function pieform_rule_integer_i18n() {/*{{{*/
         'es.utf8' => array(
             'integer'   => 'Este campo debe ser un número entero'
         ),
+        'sl.utf8' => array(
+            'integer'   => 'Vrednost polja mora biti število'
+        ),
+        'nl.utf8' => array(
+            'integer'   => 'Dit veld moet een geheel getal (integer) zijn'
+        ),
+        'cs.utf8' => array(
+            'integer'   => 'Musíte zadat celé číslo'
+        ),
 
     );
 }/*}}}*/
