@@ -56,6 +56,15 @@ function pieform_rule_maxlength_i18n() {/*{{{*/
         'es.utf8' => array(
             'maxlength' => 'Este campo tiene que tener como máximo %d caracteres'
         ),
+        'sl.utf8' => array(
+            'maxlength' => 'To polje mora biti dolgo največ %d znakov'
+        ),
+        'nl.utf8' => array(
+            'maxlength' => 'Dit veld moet minstens %d tekens lang zijn'
+        ),
+        'cs.utf8' => array(
+            'maxlength' => 'Můžete zadat nejvýše %d znaků'
+        ),
 
     );
 }/*}}}*/
