@@ -1,7 +1,8 @@
 <?php
 /**
  * Mahara: Electronic portfolio, weblog, resume builder and social networking
- * Copyright (C) 2006-2008 Catalyst IT Ltd (http://www.catalyst.net.nz)
+ * Copyright (C) 2006-2009 Catalyst IT Ltd and others; see:
+ *                         http://wiki.mahara.org/Contributors
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -20,197 +21,100 @@
  * @subpackage core
  * @author     Catalyst IT Ltd
  * @license    http://www.gnu.org/copyleft/gpl.html GNU GPL
- * @copyright  (C) 2006-2008 Catalyst IT Ltd http://catalyst.net.nz
+ * @copyright  (C) 2006-2009 Catalyst IT Ltd http://catalyst.net.nz
  *
  */
 define('INTERNAL', 1);
+define('PUBLIC', 1);
+// Technically these are lies, but we set them like this to hook in the right 
+// plugin stylesheet. This file should be provided by artefact/internal anyway.
+define('SECTION_PLUGINTYPE', 'artefact');
+define('SECTION_PLUGINNAME', 'internal');
+define('SECTION_PAGE', 'view');
+
 require(dirname(dirname(__FILE__)).'/init.php');
 require_once('group.php');
 require_once('pieforms/pieform.php');
+require_once(get_config('libroot') . 'view.php');
 
-$userid = param_integer('id','');
 $loggedinid = $USER->get('id');
+if (!empty($loggedinid)) {
+    $userid = param_integer('id', $loggedinid);
+}
+else {
+    $userid = param_integer('id');
+}
+if ($userid == 0) {
+    redirect();
+}
+if ($userid == $loggedinid) {
+    define('MENUITEM', 'profile/view');
+}
 
 // Get the user's details
 
-$profile = array();
-$userfields = array();
 if (!$user = get_record('usr', 'id', $userid, 'deleted', 0)) {
     throw new UserNotFoundException("User with id $userid not found");
 }
 $is_friend = is_friend($userid, $loggedinid);
 
+$userobj = new User();
+$userobj->find_by_id($userid);
+$view = $userobj->get_profile_view();
+# access will either be logged in (always) or public as well
+if (!$view || !can_view_view($view->get('id'))) {
+    throw new AccessDeniedException(get_string('youcannotviewthisusersprofile'));
+}
+
 $name = display_name($user);
 define('TITLE', $name);
-
-// If the logged in user is on staff, get full name, institution, id number, email address
-if ($USER->is_staff_for_user($user)) {
-    $userfields['fullname']     = $user->firstname . ' ' . $user->lastname;
-    $institutions = get_column_sql('
-        SELECT i.displayname
-        FROM {institution} i, {usr_institution} ui 
-        WHERE ui.usr = ? AND ui.institution = i.name', array($user->id));
-    if (!empty($institutions)) {
-        $userfields['institution'] = join(', ', $institutions);
-    } else {
-        $userfields['institution'] = get_field('institution', 'displayname', 'name', 'mahara');
-    }
-    $userfields['studentid']    = get_profile_field($user->id, 'studentid');
-    $userfields['principalemailaddress'] = $user->email;
-}
-
-// Get public profile fields:
-safe_require('artefact', 'internal');
-if ($USER->is_admin_for_user($user)) {
-    $publicfields = call_static_method(generate_artefact_class_name('profile'),'get_all_fields');
-}
-else {
-    $publicfields = call_static_method(generate_artefact_class_name('profile'),'get_public_fields');
-}
-foreach (array_keys($publicfields) as $field) {
-    $classname = generate_artefact_class_name($field);
-    if ($field == 'email') {  // There may be multiple email records
-        if ($emails = get_records_array('artefact_internal_profile_email', 'owner', $userid)) {
-            foreach ($emails as $email) {
-                $fieldname = $email->principal ? 'principalemailaddress' : 'emailaddress';
-                $userfields[$fieldname] = $email->email;
-            }
-        }
-    }
-    else {
-        $value = get_profile_field($userid, $field);
-        if (!empty($value)) {
-            $userfields[$field] = $value;
-        }
-    }
-}
-if (isset($userfields['country'])) {
-    $userfields['country'] = get_string('country.' . $userfields['country']);
-}
-
-if (isset($userfields['firstname'])) {
-    unset($userfields['firstname']);
-}
-
-if (isset($userfields['lastname'])) {
-    unset($userfields['lastname']);
-}
-
-if (isset($userfields['introduction'])) {
-    $introduction = $userfields['introduction'];
-    unset($userfields['introduction']);
-}
-
-// Get viewable views
-$views = array();
-if ($allviews = get_records_array('view', 'owner', $userid)) {
-    foreach ($allviews as $view) {
-        if (can_view_view($view->id)) {
-            $views[$view->id] = $view;
-            $view->artefacts = array();
-            $view->description = str_shorten($view->description, 100, true);
-        }
-    }
-}
-
-if ($views) {
-    $viewidlist = implode(', ', array_map(create_function('$a', 'return $a->id;'), $views));
-    $artefacts = get_records_sql_array('SELECT va.view, va.artefact, a.title, a.artefacttype, t.plugin
-        FROM {view_artefact} va
-        INNER JOIN {artefact} a ON va.artefact = a.id
-        INNER JOIN {artefact_installed_type} t ON a.artefacttype = t.name
-        WHERE va.view IN (' . $viewidlist . ')
-        GROUP BY 1, 2, 3, 4, 5
-        ORDER BY a.title, va.artefact', '');
-    if ($artefacts) {
-        foreach ($artefacts as $artefactrec) {
-            safe_require('artefact', $artefactrec->plugin);
-            // Perhaps I shouldn't have to construct the entire
-            // artefact object to render the name properly.
-            $classname = generate_artefact_class_name($artefactrec->artefacttype);
-            $artefactobj = new $classname(0, array('title' => $artefactrec->title));
-            $artefactobj->set('dirty', false);
-            if (!$artefactobj->in_view_list()) {
-                continue;
-            }
-            $artname = $artefactobj->display_title(30);
-            if (strlen($artname)) {
-                $views[$artefactrec->view]->artefacts[] = array('id'    => $artefactrec->artefact,
-                                                                'title' => $artname);
-            }
-        }
-    }
-}
-
-// Group stuff
-if (!$userassocgroups = get_associated_groups($userid, false)) {
-    $userassocgroups = array();
-}
-
-foreach ($userassocgroups as $group) {
-    $group->description = str_shorten($group->description, 100, true);
-}
-
-if (is_postgres()) {
-    $random = 'RANDOM()';
-}
-else if (is_mysql()) {
-    $random = 'RAND()';
-}
-
-$records = get_records_sql_array('SELECT usr1, usr2 FROM {usr_friend}
-    JOIN {usr} u1 ON (u1.id = usr1 AND u1.deleted = 0)
-    JOIN {usr} u2 ON (u2.id = usr2 AND u2.deleted = 0)
-    WHERE usr1 = ? OR usr2 = ?
-    ORDER BY ' . $random . '
-    LIMIT ?',
-    array($userid, $userid, 16)
+$smarty = smarty(
+    array('lib/pieforms/static/core/pieforms.js'),
+    array('<link rel="stylesheet" type="text/css" href="' . get_config('wwwroot') . 'theme/views.css">'),
+    array(),
+    array(
+        'stylesheets' => array('style/views.css'),
+    )
 );
-$numberoffriends = count_records_sql('SELECT COUNT(usr1) FROM {usr_friend}
-    JOIN {usr} u1 ON (u1.id = usr1 AND u1.deleted = 0)
-    JOIN {usr} u2 ON (u2.id = usr2 AND u2.deleted = 0)
-    WHERE usr1 = ? OR usr2 = ?',
-    array($userid, $userid)
-);
-if ($numberoffriends > 16) {
-    $friendsmessage = get_string('numberoffriends', 'group', $records ? count($records) : 0, $numberoffriends);
-}
-else {
-    $friendsmessage = get_string('Friends', 'group');
-}
-// get the friends into a 4x4 array
-if ($records) {
-    $friends = array();
-    for ($i = 0; $i < 4; $i++) {
-        $friends[$i] = array();
-        for($j = 4 * $i; $j < ($i + 1 ) * 4; $j++) {
-            if (isset($records[$j])) {
-                if ($records[$j]->usr1 == $userid) {
-                    $friends[$i][] = $records[$j]->usr2;
-                }
-                else {
-                    $friends[$i][] = $records[$j]->usr1;
-                }
-            }
-        }
-    }
-}
-else {
-    $friends = false;
-}
 
-$smarty = smarty();
-$allusergroups = get_associated_groups($userid);
-if ($loggedinid != $userid) {
+$sql = "SELECT g.*, a.type FROM {group} g JOIN (
+SELECT gm.group, 'invite' AS type
+    FROM {group_member_invite} gm WHERE gm.member = ?
+UNION
+SELECT gm.group, 'request' AS type
+    FROM {group_member_request} gm WHERE gm.member = ?
+UNION
+SELECT gm.group, gm.role AS type
+    FROM {group_member} gm
+    WHERE gm.member = ?
+) AS a ON a.group = g.id
+WHERE g.deleted = 0
+ORDER BY g.name";
+if (!$allusergroups = get_records_sql_assoc($sql, array($userid, $userid, $userid))) {
+    $allusergroups = array();
+}
+if (!empty($loggedinid) && $loggedinid != $userid) {
+
+    $invitedlist = array();   // Groups admin'ed by the logged in user that the displayed user has been invited to
+    $requestedlist = array(); // Groups admin'ed by the logged in user that the displayed user has requested membership of
+
     // Get the logged in user's "invite only" groups
-    if ($groups = get_owned_groups($loggedinid, 'invite')) {
+    if ($groups = get_records_sql_array("SELECT g.*
+        FROM {group} g
+        JOIN {group_member} gm ON (gm.group = g.id)
+        WHERE gm.member = ?
+        AND g.jointype = 'invite'
+        AND gm.role = 'admin'
+        AND g.deleted = 0", array($loggedinid))) {
         $invitelist = array();
         foreach ($groups as $group) {
-            if ($allusergroups && array_key_exists($group->id, $allusergroups)) {
+            if (array_key_exists($group->id, $allusergroups)) {
+                $invitedlist[$group->id] = $group->name;
                 continue;
             }
             $invitelist[$group->id] = $group->name;
         }
+        $smarty->assign('invitedlist', join(', ', $invitedlist));
         if (count($invitelist) > 0) {
             $default = array_keys($invitelist);
             $default = $default[0];
@@ -240,15 +144,33 @@ if ($loggedinid != $userid) {
         }
     }
 
-    // Get the "controlled membership" groups in which the logged in user is a tutor
-    if ($groups = get_tutor_groups($loggedinid, 'controlled')) {
+    // Get (a) controlled membership groups,
+    //     (b) request membership groups where the displayed user has requested membership,
+    // where the logged in user either:
+    // 1. is a group admin, or;
+    // 2. has a role in the list of roles who are allowed to assess submitted views for the given grouptype
+    if ($groups = get_records_sql_array("SELECT g.*, gm.ctime
+          FROM {group} g
+          JOIN {group_member} gm ON (gm.group = g.id)
+          JOIN {grouptype_roles} gtr ON (gtr.grouptype = g.grouptype AND gtr.role = gm.role)
+          LEFT JOIN {group_member_request} gmr ON (gmr.member = ? AND gmr.group = g.id)
+          WHERE gm.member = ?
+          AND (g.jointype = 'controlled' OR (g.jointype = 'request' AND gmr.member = ?))
+          AND (gm.role = 'admin' OR gtr.see_submitted_views = 1)
+          AND g.deleted = 0", array($userid,$loggedinid,$userid))) {
         $controlledlist = array();
         foreach ($groups as $group) {
-            if (array_key_exists($group->id, $userassocgroups)) {
+            if (array_key_exists($group->id, $allusergroups)) {
                 continue;
             }
-            $controlledlist[$group->id] = $group->name;
+            if ($group->jointype == 'request') {
+                $requestedlist[$group->id] = $group->name;
+            }
+            else {
+                $controlledlist[$group->id] = $group->name;
+            }
         }
+        $smarty->assign('requestedlist', join(', ', $requestedlist));
         if (count($controlledlist) > 0) {
             $default = array_keys($controlledlist);
             $default = $default[0];
@@ -256,6 +178,7 @@ if ($loggedinid != $userid) {
                 'name'                => 'addmember',
                 'successcallback'     => 'addmember_submit',
                 'renderer'            => 'div',
+                'autofocus'           => false,
                 'elements'            => array(
                     'group' => array(
                         'type'    => 'select',
@@ -264,12 +187,16 @@ if ($loggedinid != $userid) {
                         'options' => $controlledlist,
                         'defaultvalue' => $default,
                     ),
+                    'member' => array(
+                        'type'  => 'hidden',
+                        'value' => $userid, 
+                    ),
                     'submit' => array(
                         'type'  => 'submit',
                         'value' => get_string('add'),
                     ),
                 ),
-           ));
+            ));
             $smarty->assign('addform',$addform);
         } 
     }
@@ -330,9 +257,35 @@ if ($loggedinid != $userid) {
     $smarty->assign('relationship', $relationship);
 
 }
+else if (!empty($loggedinid)) {
+    if (get_config('allowpublicprofiles')) {
+        $public = array_filter($view->get_access(), 
+            create_function(
+                '$item', 
+                'return $item[\'type\'] == \'public\';'
+            )
+        );
+        $togglepublic = pieform(array(
+            'name'      => 'togglepublic',
+            'autofocus' => false,
+            'renderer'  => 'div',
+            'elements'  => array(
+                'changeto' => array(
+                    'type'  => 'hidden',
+                    'value' => ($public) ? 'loggedin' : 'public'
+                ),
+                'submit' => array(
+                    'type' => 'submit',
+                    'value' => ($public) ? get_string('loggedinusersonly') : get_string('allowpublicaccess'),
+                ),
+            ),
+        ));
+        $smarty->assign('togglepublic', $togglepublic);
+    }
+}
 
 if ($userid != $USER->get('id') && $USER->is_admin_for_user($user) && is_null($USER->get('parentuser'))) {
-    $loginas = get_string('loginasuser', 'admin', $user->username);
+    $loginas = get_string('loginasuser', 'admin', hsc($user->username));
 } else {
     $loginas = null;
 }
@@ -341,14 +294,12 @@ $smarty->assign('loginas', $loginas);
 if (isset($introduction)) {
     $smarty->assign('introduction', $introduction);
 }
+$smarty->assign('institutions', get_institution_string_for_user($userid));
 $smarty->assign('canmessage', can_send_message($loggedinid, $userid));
 $smarty->assign('NAME',$name);
 $smarty->assign('USERID', $userid);
-$smarty->assign('USERFIELDS',$userfields);
-$smarty->assign('USERGROUPS',$userassocgroups);
-$smarty->assign('VIEWS',$views);
-$smarty->assign('friends', $friends);
-$smarty->assign('friendsmessage', $friendsmessage);
+$smarty->assign('viewcontent', $view->build_columns());
+$smarty->assign('PAGEHEADING', hsc(TITLE));
 $smarty->display('user/view.tpl');
 
 // Send an invitation to the user to join a group
@@ -365,13 +316,15 @@ function addmember_submit(Pieform $form, $values) {
     $data->group  = $values['group'];
     $data->member = $userid;
     $data->ctime  = db_format_timestamp(time());
-    $data->tutor  = 0;
+    $data->role  = 'member'; // TODO: modify the dropdown to allow the role to be chosen
     $ctitle = get_field('group', 'name', 'id', $data->group);
     $adduser = get_record('usr', 'id', $data->member);
 
     try {
         insert_record('group_member', $data);
+        delete_records('group_member_request', 'member', $userid, 'group', $data->group);
         $lang = get_user_language($userid);
+        require_once(get_config('libroot') . 'activity.php');
         activity_occurred('maharamessage', 
             array('users'   => array($userid),
                   'subject' => get_string_from_language($lang, 'addedtogroupsubject', 'group'),
@@ -394,4 +347,27 @@ function approve_deny_friendrequest_submit(Pieform $form, $values) {
     }
 }
 
+function togglepublic_submit(Pieform $form, $values) {
+    global $SESSION, $userid, $view;
+    $access = array(
+        array(
+            'type'      => 'loggedin',
+            'startdate' => null,
+            'stopdate'  => null,
+        ),
+    );
+
+    if ($values['changeto'] == 'public') {
+        $access[] = array(
+            'type'      => 'public',
+            'startdate' => null,
+            'stopdate'  => null,
+        );
+    }
+    $view->set_access($access);
+    $SESSION->add_ok_msg(get_string('viewaccesseditedsuccessfully', 'view'));
+
+    redirect('/user/view.php?id=' . $userid);
+}
+
 ?>
