@@ -1,7 +1,8 @@
 <?php
 /**
  * Mahara: Electronic portfolio, weblog, resume builder and social networking
- * Copyright (C) 2006-2008 Catalyst IT Ltd (http://www.catalyst.net.nz)
+ * Copyright (C) 2006-2009 Catalyst IT Ltd and others; see:
+ *                         http://wiki.mahara.org/Contributors
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -20,7 +21,7 @@
  * @subpackage core
  * @author     Catalyst IT Ltd
  * @license    http://www.gnu.org/copyleft/gpl.html GNU GPL
- * @copyright  (C) 2006-2008 Catalyst IT Ltd http://catalyst.net.nz
+ * @copyright  (C) 2006-2009 Catalyst IT Ltd http://catalyst.net.nz
  *
  */
 
@@ -31,7 +32,7 @@ define('INTERNAL', 1);
 define('JSON', 1);
 
 require(dirname(dirname(__FILE__)) . '/init.php');
-require('searchlib.php');
+require_once('searchlib.php');
 
 $type   = param_variable('type');
 $query  = param_variable('query', '');
@@ -44,6 +45,11 @@ switch ($type) {
         break;
     case 'group':
         $data = search_group($query, $limit, $offset, '');
+        $roles = get_records_array('grouptype_roles');
+        $data['roles'] = array();
+        foreach ($roles as $r) {
+            $data['roles'][$r->grouptype][] = array('name' => $r->role, 'display' => get_string($r->role, 'grouptype.'.$r->grouptype));
+        }
         break;
 }
 
